@@ -1,40 +1,22 @@
 # This file is part of ReText
-# Copyright: Dmitry Shachnev 2012
+# Copyright: Dmitry Shachnev 2012-2014
 # License: GNU GPL v2 or higher
 
 import markups
 import markups.common
-import sys
 from os.path import join, abspath
 
-if '--pyqt4' in sys.argv:
-	from PyQt4 import QtCore, QtGui, QtWebKit
-elif '--pyside' in sys.argv:
-	from PySide import QtCore, QtGui, QtWebKit
-else:
-	try:
-		from PyQt5 import QtCore, QtPrintSupport, QtGui, QtWidgets, QtWebKit, QtWebKitWidgets
-	except ImportError:
-		try:
-			from PyQt4 import QtCore, QtGui, QtWebKit
-		except ImportError:
-			from PySide import QtCore, QtGui, QtWebKit
-
-if not 'QtWidgets' in locals():
-	# PyQt4 or PySide
-	QtPrintSupport, QtWidgets, QtWebKitWidgets = QtGui, QtGui, QtWebKit
-
-(QByteArray, QDir, QSettings) = (QtCore.QByteArray, QtCore.QDir, QtCore.QSettings)
-QFont = QtGui.QFont
+from PyQt5.QtCore import QByteArray, QLocale, QSettings, QStandardPaths
+from PyQt5.QtGui import QFont
 
 app_name = "ReText"
-app_version = "4.1.2"
+app_version = "5.0.1"
 
 settings = QSettings('ReText project', 'ReText')
 
 if not str(settings.fileName()).endswith('.conf'):
 	# We are on Windows probably
-	settings = QSettings(QSettings.IniFormat, QSettings.UserScope, 
+	settings = QSettings(QSettings.IniFormat, QSettings.UserScope,
 		'ReText project', 'ReText')
 
 try:
@@ -61,6 +43,7 @@ configOptions = {
 	'appStyleSheet': '',
 	'autoPlainText': True,
 	'autoSave': False,
+	'colorSchemeFile': '',
 	'defaultMarkup': '',
 	'editorFont': 'monospace',
 	'editorFontSize': 0,
@@ -81,6 +64,7 @@ configOptions = {
 	'styleSheet': '',
 	'tabInsertsSpaces': True,
 	'tabWidth': 4,
+	'uiLanguage': QLocale.system().name(),
 	'useWebKit': False,
 	'windowGeometry': QByteArray(),
 }
@@ -92,10 +76,6 @@ def readFromSettings(key, keytype, settings=settings, default=None):
 		value = settings.value(key, type=keytype)
 		if isinstance(value, keytype):
 			return value
-		# PySide returns strings instead of ints and bools
-		if (isinstance(value, str) and value.lower() == 'false'
-		and keytype is bool):
-			return False
 		return keytype(value)
 	except TypeError as error:
 		# Type mismatch
@@ -132,7 +112,7 @@ class ReTextSettings(object):
 			value = configOptions[option]
 			object.__setattr__(self, option, readFromSettings(
 				option, type(value), default=value))
-	
+
 	def __setattr__(self, option, value):
 		if not option in configOptions:
 			raise AttributeError('Unknown attribute')
@@ -148,15 +128,5 @@ monofont.setFamily(globalSettings.editorFont)
 if globalSettings.editorFontSize:
 	monofont.setPointSize(globalSettings.editorFontSize)
 
-currentpath = abspath('.')
-if hasattr(QtCore, 'QStandardPaths'):
-	datadirs = QtCore.QStandardPaths.standardLocations(
-		QtCore.QStandardPaths.GenericDataLocation)
-	datadirs = [currentpath] + [join(d, 'retext') for d in datadirs]
-else:
-	datadirs = (
-		currentpath,
-		'/usr/share/retext',
-		'/usr/local/share/retext',
-		QDir.homePath()+'/.local/share/retext'
-	)
+datadirs = QStandardPaths.standardLocations(QStandardPaths.GenericDataLocation)
+datadirs = [abspath('.')] + [join(d, 'retext') for d in datadirs]
