@@ -1,28 +1,72 @@
+# vim: noexpandtab:ts=4:sw=4
 # This file is part of ReText
-# Copyright: Dmitry Shachnev 2012
+# Copyright: Dmitry Shachnev 2012-2014
 # License: GNU GPL v2 or higher
 
-from ReText import QtCore, QtGui, QtWidgets, monofont, globalSettings, DOCTYPE_MARKDOWN
+from ReText import monofont, globalSettings, tablemode, DOCTYPE_MARKDOWN
 
-(QPoint, QSize, Qt) = (QtCore.QPoint, QtCore.QSize, QtCore.Qt)
-(QColor, QPainter, QTextCursor, QTextFormat) = (QtGui.QColor, QtGui.QPainter,
- QtGui.QTextCursor, QtGui.QTextFormat)
-(QTextEdit, QWidget) = (QtWidgets.QTextEdit, QtWidgets.QWidget)
+from PyQt5.QtCore import QPoint, QSize, Qt
+from PyQt5.QtGui import QColor, QPainter, QTextCursor, QTextFormat
+from PyQt5.QtWidgets import QTextEdit, QWidget
+
+def documentIndentMore(document, cursor, globalSettings=globalSettings):
+	if cursor.hasSelection():
+		block = document.findBlock(cursor.selectionStart())
+		end = document.findBlock(cursor.selectionEnd()).next()
+		cursor.beginEditBlock()
+		while block != end:
+			cursor.setPosition(block.position())
+			if globalSettings.tabInsertsSpaces:
+				cursor.insertText(' ' * globalSettings.tabWidth)
+			else:
+				cursor.insertText('\t')
+			block = block.next()
+		cursor.endEditBlock()
+	else:
+		indent = globalSettings.tabWidth - (cursor.positionInBlock()
+			% globalSettings.tabWidth)
+		if globalSettings.tabInsertsSpaces:
+			cursor.insertText(' ' * indent)
+		else:
+			cursor.insertText('\t')
+
+def documentIndentLess(document, cursor, globalSettings=globalSettings):
+	if cursor.hasSelection():
+		block = document.findBlock(cursor.selectionStart())
+		end = document.findBlock(cursor.selectionEnd()).next()
+	else:
+		block = document.findBlock(cursor.position())
+		end = block.next()
+	cursor.beginEditBlock()
+	while block != end:
+		cursor.setPosition(block.position())
+		if document.characterAt(cursor.position()) == '\t':
+			cursor.deleteChar()
+		else:
+			pos = 0
+			while document.characterAt(cursor.position()) == ' ' \
+			and pos < globalSettings.tabWidth:
+				pos += 1
+				cursor.deleteChar()
+		block = block.next()
+	cursor.endEditBlock()
 
 class ReTextEdit(QTextEdit):
 	def __init__(self, parent):
 		QTextEdit.__init__(self)
 		self.parent = parent
+		self.undoRedoActive = False
+		self.tableModeEnabled = False
 		self.setFont(monofont)
 		self.setAcceptRichText(False)
 		self.marginx = (self.cursorRect(self.cursorForPosition(QPoint())).topLeft().x()
 			+ self.fontMetrics().width(" "*globalSettings.rightMargin))
-		if globalSettings.lineNumbersEnabled:
-			self.lineNumberArea = LineNumberArea(self)
-			self.document().blockCountChanged.connect(self.updateLineNumberAreaWidth)
-			self.updateLineNumberAreaWidth()
+		self.lineNumberArea = LineNumberArea(self)
+		self.document().blockCountChanged.connect(self.updateLineNumberAreaWidth)
+		self.updateLineNumberAreaWidth()
 		self.cursorPositionChanged.connect(self.highlightCurrentLine)
-	
+		self.document().contentsChange.connect(self.contentsChange)
+
 	def paintEvent(self, event):
 		if not globalSettings.rightMargin:
 			return QTextEdit.paintEvent(self, event)
@@ -32,11 +76,10 @@ class ReTextEdit(QTextEdit):
 		y2 = self.rect().bottomLeft().y()
 		painter.drawLine(self.marginx, y1, self.marginx, y2)
 		QTextEdit.paintEvent(self, event)
-	
+
 	def scrollContentsBy(self, dx, dy):
 		QTextEdit.scrollContentsBy(self, dx, dy)
-		if hasattr(self, 'lineNumberArea'):
-			self.lineNumberArea.repaint()
+		self.lineNumberArea.repaint()
 
 	def lineNumberAreaPaintEvent(self, event):
 		painter = QPainter(self.lineNumberArea)
@@ -56,10 +99,10 @@ class ReTextEdit(QTextEdit):
 			atEnd = cursor.atEnd()
 			if not atEnd:
 				cursor.movePosition(QTextCursor.NextBlock)
-	
+
 	def getHighlighter(self):
 		return self.parent.highlighters[self.parent.ind]
-	
+
 	def contextMenuEvent(self, event):
 		text = self.toPlainText()
 		dictionary = self.getHighlighter().dictionary
@@ -85,19 +128,21 @@ class ReTextEdit(QTextEdit):
 		menu = self.createStandardContextMenu()
 		menu.insertSeparator(menu.actions()[0])
 		for action in actions[::-1]:
-			menu.insertAction(menu.actions()[0], action) 
-		menu.exec_(event.globalPos())
-	
+			menu.insertAction(menu.actions()[0], action)
+		menu.exec(event.globalPos())
+
 	def fixWord(self, correctword):
 		return lambda: self.insertPlainText(correctword)
-	
+
 	def keyPressEvent(self, event):
 		key = event.key()
 		cursor = self.textCursor()
+		if event.text() and self.tableModeEnabled:
+			cursor.beginEditBlock()
 		if key == Qt.Key_Tab:
-			self.indentMore()
+			documentIndentMore(self.document(), cursor)
 		elif key == Qt.Key_Backtab:
-			self.indentLess()
+			documentIndentLess(self.document(), cursor)
 		elif key == Qt.Key_Return and not cursor.hasSelection():
 			if event.modifiers() & Qt.ShiftModifier:
 				# Insert Markdown-style line break
@@ -110,83 +155,41 @@ class ReTextEdit(QTextEdit):
 				self.handleReturn(cursor)
 		else:
 			QTextEdit.keyPressEvent(self, event)
-	
+		if event.text() and self.tableModeEnabled:
+			cursor.endEditBlock()
+
 	def handleReturn(self, cursor):
 		# Select text between the cursor and the line start
 		cursor.movePosition(QTextCursor.StartOfBlock, QTextCursor.KeepAnchor)
 		text = cursor.selectedText()
 		length = len(text)
 		pos = 0
-		while pos < length and text[pos] in (' ', '\t'):
+		while pos < length and (text[pos] in (' ', '\t')
+		  or text[pos:pos+2] in ('* ', '- ')):
 			pos += 1
 		# Reset the cursor
 		cursor = self.textCursor()
 		cursor.insertText('\n'+text[:pos])
 		self.ensureCursorVisible()
-	
-	def indentMore(self):
-		cursor = self.textCursor()
-		if cursor.hasSelection():
-			block = self.document().findBlock(cursor.selectionStart())
-			end = self.document().findBlock(cursor.selectionEnd()).next()
-			cursor.beginEditBlock()
-			while block != end:
-				cursor.setPosition(block.position())
-				if globalSettings.tabInsertsSpaces:
-					cursor.insertText(' ' * globalSettings.tabWidth)
-				else:
-					cursor.insertText('\t')
-				block = block.next()
-			cursor.endEditBlock()
-		else:
-			indent = globalSettings.tabWidth - (cursor.positionInBlock()
-				% globalSettings.tabWidth)
-			if globalSettings.tabInsertsSpaces:
-				cursor.insertText(' ' * indent)
-			else:
-				cursor.insertText('\t')
-	
-	def indentLess(self):
-		cursor = self.textCursor()
-		document = self.document()
-		if cursor.hasSelection():
-			block = document.findBlock(cursor.selectionStart())
-			end = document.findBlock(cursor.selectionEnd()).next()
-		else:
-			block = document.findBlock(cursor.position())
-			end = block.next()
-		cursor.beginEditBlock()
-		while block != end:
-			cursor.setPosition(block.position())
-			if document.characterAt(cursor.position()) == '\t':
-				cursor.deleteChar()
-			else:
-				pos = 0
-				while document.characterAt(cursor.position()) == ' ' \
-				and pos < globalSettings.tabWidth:
-					pos += 1
-					cursor.deleteChar()
-			block = block.next()
-		cursor.endEditBlock()
-	
+
 	def lineNumberAreaWidth(self):
+		if not globalSettings.lineNumbersEnabled:
+			return 0
 		cursor = QTextCursor(self.document())
 		cursor.movePosition(QTextCursor.End)
 		digits = len(str(cursor.blockNumber() + 1))
 		return 5 + self.fontMetrics().width('9') * digits
-	
+
 	def updateLineNumberAreaWidth(self, blockcount=0):
 		self.lineNumberArea.repaint()
 		self.setViewportMargins(self.lineNumberAreaWidth(), 0, 0, 0)
-	
+
 	def resizeEvent(self, event):
 		QTextEdit.resizeEvent(self, event)
-		if not globalSettings.lineNumbersEnabled:
-			return
 		rect = self.contentsRect()
 		self.lineNumberArea.setGeometry(rect.left(), rect.top(),
 			self.lineNumberAreaWidth(), rect.height())
-	
+
 	def highlightCurrentLine(self):
 		if not globalSettings.highlightCurrentLine:
 			return self.setExtraSelections([])
@@ -198,13 +201,34 @@ class ReTextEdit(QTextEdit):
 		selection.cursor.clearSelection()
 		self.setExtraSelections([selection])
 
+	def enableTableMode(self, enable):
+		self.tableModeEnabled = enable
+
+	def backupCursorPositionOnLine(self):
+		return self.textCursor().positionInBlock()
+
+	def restoreCursorPositionOnLine(self, positionOnLine):
+		cursor = self.textCursor()
+		cursor.setPosition(cursor.block().position() + positionOnLine)
+		self.setTextCursor(cursor)
+
+	def contentsChange(self, pos, removed, added):
+		if self.tableModeEnabled:
+			markupClass = self.parent.getMarkupClass()
+			docType = markupClass.name if markupClass else None
+
+			cursorPosition = self.backupCursorPositionOnLine()
+			tablemode.adjustTableToChanges(self.document(), pos, added - removed, docType)
+			self.restoreCursorPositionOnLine(cursorPosition)
+
 class LineNumberArea(QWidget):
 	def __init__(self, editor):
 		QWidget.__init__(self, editor)
 		self.editor = editor
-	
+
 	def sizeHint(self):
 		return QSize(self.editor.lineNumberAreaWidth(), 0)
-	
+
 	def paintEvent(self, event):
-		return self.editor.lineNumberAreaPaintEvent(event)
+		if globalSettings.lineNumbersEnabled:
+			return self.editor.lineNumberAreaPaintEvent(event)
