@@ -1,50 +1,30 @@
+# vim: noexpandtab:ts=4:sw=4
 # This file is part of ReText
-# Copyright: Dmitry Shachnev 2012
+# Copyright: Dmitry Shachnev 2012-2014
 # License: GNU GPL v2 or higher
 
 import markups
-from subprocess import Popen, PIPE
-from ReText import QtCore, QtPrintSupport, QtGui, QtWidgets, QtWebKitWidgets, \
- icon_path, DOCTYPE_MARKDOWN, DOCTYPE_REST, app_name, app_version, globalSettings, \
- settings, readListFromSettings, writeListToSettings, writeToSettings, \
- datadirs, enchant, enchant_available
+import sys
+from subprocess import Popen
+from ReText import icon_path, DOCTYPE_MARKDOWN, DOCTYPE_REST, app_name, \
+ app_version, globalSettings, settings, readListFromSettings, \
+ writeListToSettings, writeToSettings, datadirs, enchant, enchant_available
 from ReText.webpages import wpInit, wpUpdateAll
 from ReText.dialogs import HtmlDialog, LocaleDialog
 from ReText.config import ConfigDialog
 from ReText.highlighter import ReTextHighlighter
 from ReText.editor import ReTextEdit
 
-(QDir, QFile, QFileInfo, QIODevice, QLocale, QRect, QTemporaryFile, QTextCodec,
- QTextStream, QTimer, QUrl, Qt) = (QtCore.QDir, QtCore.QFile, QtCore.QFileInfo,
- QtCore.QIODevice, QtCore.QLocale, QtCore.QRect, QtCore.QTemporaryFile,
- QtCore.QTextCodec, QtCore.QTextStream, QtCore.QTimer, QtCore.QUrl, QtCore.Qt)
-(QDesktopServices, QFont, QFontMetrics, QIcon, QKeySequence, QTextCursor,
- QTextDocument) = (QtGui.QDesktopServices, QtGui.QFont, QtGui.QFontMetrics,
- QtGui.QIcon, QtGui.QKeySequence, QtGui.QTextCursor, QtGui.QTextDocument)
-(QAction, QActionGroup, QApplication, QCheckBox, QComboBox, QDesktopWidget, QDialog,
- QFileDialog, QFontDialog, QInputDialog, QLabel, QLineEdit, QMainWindow, QMenuBar,
- QMessageBox, QSplitter, QTabWidget, QTextBrowser, QTextEdit, QToolBar) = (
- QtWidgets.QAction, QtWidgets.QActionGroup, QtWidgets.QApplication, QtWidgets.QCheckBox,
- QtWidgets.QComboBox, QtWidgets.QDesktopWidget, QtWidgets.QDialog, QtWidgets.QFileDialog,
- QtWidgets.QFontDialog, QtWidgets.QInputDialog, QtWidgets.QLabel, QtWidgets.QLineEdit,
- QtWidgets.QMainWindow, QtWidgets.QMenuBar, QtWidgets.QMessageBox, QtWidgets.QSplitter,
- QtWidgets.QTabWidget, QtWidgets.QTextBrowser, QtWidgets.QTextEdit, QtWidgets.QToolBar)
-(QPrintDialog, QPrintPreviewDialog, QPrinter) = (QtPrintSupport.QPrintDialog,
- QtPrintSupport.QPrintPreviewDialog, QtPrintSupport.QPrinter)
-(QWebPage, QWebView) = (QtWebKitWidgets.QWebPage, QtWebKitWidgets.QWebView)
-
-useAppDisplayName = hasattr(QApplication, 'applicationDisplayName')
-
-def getSaveFileName(*args):
-	result = QFileDialog.getSaveFileName(*args)
-	return result[0] if isinstance(result, tuple) else result
-
-def setWindowTitle(window, title):
-	if not useAppDisplayName:
-		title += ' \u2014 ' + app_name
-	QMainWindow.setWindowTitle(window, title)
-
-dialogTitle = '' if useAppDisplayName else app_name
+from PyQt5.QtCore import QDir, QFile, QFileInfo, QIODevice, QLocale, QRect, \
+ QTextCodec, QTextStream, QTimer, QUrl, Qt
+from PyQt5.QtGui import QColor, QDesktopServices, QFont, QFontMetrics, QIcon, \
+ QKeySequence, QPalette, QTextCursor, QTextDocument, QTextDocumentWriter
+from PyQt5.QtWidgets import QAction, QActionGroup, QApplication, QCheckBox, \
+ QComboBox, QDesktopWidget, QDialog, QFileDialog, QFontDialog, QInputDialog, \
+ QLineEdit, QMainWindow, QMenuBar, QMessageBox, QSplitter, QTabWidget, \
+ QTextBrowser, QTextEdit, QToolBar
+from PyQt5.QtPrintSupport import QPrintDialog, QPrintPreviewDialog, QPrinter
+from PyQt5.QtWebKitWidgets import QWebPage, QWebView
 
 class ReTextWindow(QMainWindow):
 	def __init__(self, parent=None):
@@ -59,17 +39,6 @@ class ReTextWindow(QMainWindow):
 			self.move((screen.width()-size.width())/2, (screen.height()-size.height())/2)
 		if globalSettings.iconTheme:
 			QIcon.setThemeName(globalSettings.iconTheme)
-		if QIcon.themeName() in ('', 'hicolor'):
-			try:
-				gconf = Popen(['gconftool-2', '--get', '/desktop/gnome/interface/icon_theme'],
-				stdout=PIPE)
-			except OSError: pass
-			else:
-				iconTheme = gconf.stdout.read().rstrip()
-				if iconTheme:
-					iconTheme = iconTheme.decode()
-					QIcon.setThemeName(iconTheme)
-					settings.setValue('iconTheme', iconTheme)
 		if QFile.exists(icon_path+'retext.png'):
 			self.setWindowIcon(QIcon(icon_path+'retext.png'))
 		elif QFile.exists('/usr/share/pixmaps/retext.png'):
@@ -81,9 +50,9 @@ class ReTextWindow(QMainWindow):
 		self.highlighters = []
 		self.markups = []
 		self.fileNames = []
-		self.apc = []
-		self.alpc = []
-		self.aptc = []
+		self.actionPreviewChecked = []
+		self.actionLivePreviewChecked = []
+		self.actionPlainTextChecked = []
 		self.tabWidget = QTabWidget(self)
 		self.initTabWidget()
 		self.setCentralWidget(self.tabWidget)
@@ -106,12 +75,18 @@ class ReTextWindow(QMainWindow):
 		self.actionSetEncoding = self.act(self.tr('Set encoding'),
 			trig=self.showEncodingDialog)
 		self.actionSetEncoding.setEnabled(False)
+		self.actionReload = self.act(self.tr('Reload'), 'view-refresh', trig=self.openFileMain)
+		self.actionReload.setEnabled(False)
 		self.actionSave = self.act(self.tr('Save'), 'document-save',
 			self.saveFile, shct=QKeySequence.Save)
 		self.actionSave.setEnabled(False)
 		self.actionSave.setPriority(QAction.LowPriority)
 		self.actionSaveAs = self.act(self.tr('Save as'), 'document-save-as',
 			self.saveFileAs, shct=QKeySequence.SaveAs)
+		self.actionNextTab = self.act(self.tr('Next tab'), 'go-next',
+			lambda: self.switchTab(1), shct=Qt.CTRL+Qt.Key_PageDown)
+		self.actionPrevTab = self.act(self.tr('Previous tab'), 'go-previous',
+			lambda: self.switchTab(-1), shct=Qt.CTRL+Qt.Key_PageUp)
 		self.actionPrint = self.act(self.tr('Print'), 'document-print',
 			self.printFile, shct=QKeySequence.Print)
 		self.actionPrint.setPriority(QAction.LowPriority)
@@ -134,11 +109,13 @@ class ReTextWindow(QMainWindow):
 			self.actionPreview.setIcon(QIcon(icon_path+'document-preview.png'))
 		self.actionLivePreview = self.act(self.tr('Live preview'), shct=Qt.CTRL+Qt.Key_L,
 		trigbool=self.enableLivePreview)
+		self.actionTableMode = self.act(self.tr('Table mode'), shct=Qt.CTRL+Qt.Key_T,
+			trigbool=lambda x: self.editBoxes[self.ind].enableTableMode(x))
 		self.actionFullScreen = self.act(self.tr('Fullscreen mode'), 'view-fullscreen',
 			shct=Qt.Key_F11, trigbool=self.enableFullScreen)
 		self.actionConfig = self.act(self.tr('Preferences'), icon='preferences-system',
 			trig=self.openConfigDialog)
-		self.actionPerfectHtml = self.act('HTML', 'text-html', self.saveFilePerfect)
+		self.actionSaveHtml = self.act('HTML', 'text-html', self.saveFileHtml)
 		self.actionPdf = self.act('PDF', 'application-pdf', self.savePdf)
 		self.actionOdf = self.act('ODT', 'x-office-document', self.saveOdf)
 		self.getExportExtensionsList()
@@ -204,7 +181,7 @@ class ReTextWindow(QMainWindow):
 		self.actionItalic = self.act(self.tr('Italic'), shct=QKeySequence.Italic,
 			trig=lambda: self.insertChars('*'))
 		self.actionUnderline = self.act(self.tr('Underline'), shct=QKeySequence.Underline,
-			trig=lambda: self.insertTag(9)) # <u>...</u>
+			trig=lambda: self.insertTag('u'))
 		self.usefulTags = ('a', 'big', 'center', 'img', 's', 'small', 'span',
 			'table', 'td', 'tr', 'u')
 		self.usefulChars = ('deg', 'divide', 'dollar', 'hellip', 'laquo', 'larr',
@@ -240,14 +217,17 @@ class ReTextWindow(QMainWindow):
 		self.menuDir.addAction(self.actionShow)
 		self.menuDir.addAction(self.actionWpgen)
 		menuFile.addAction(self.actionSetEncoding)
+		menuFile.addAction(self.actionReload)
 		menuFile.addSeparator()
 		menuFile.addAction(self.actionSave)
 		menuFile.addAction(self.actionSaveAs)
 		menuFile.addSeparator()
+		menuFile.addAction(self.actionNextTab)
+		menuFile.addAction(self.actionPrevTab)
+		menuFile.addSeparator()
 		menuExport = menuFile.addMenu(self.tr('Export'))
-		menuExport.addAction(self.actionPerfectHtml)
-		if hasattr(QtGui, 'QTextDocumentWriter'): # PYSIDE-177
-			menuExport.addAction(self.actionOdf)
+		menuExport.addAction(self.actionSaveHtml)
+		menuExport.addAction(self.actionOdf)
 		menuExport.addAction(self.actionPdf)
 		if self.extensionActions:
 			menuExport.addSeparator()
@@ -281,12 +261,12 @@ class ReTextWindow(QMainWindow):
 		menuFormat.addAction(self.actionBold)
 		menuFormat.addAction(self.actionItalic)
 		menuFormat.addAction(self.actionUnderline)
-		if QtCore.__package__ != 'PySide': # PYSIDE-213
-			menuEdit.addAction(self.actionWebKit)
+		menuEdit.addAction(self.actionWebKit)
 		menuEdit.addSeparator()
 		menuEdit.addAction(self.actionViewHtml)
 		menuEdit.addAction(self.actionLivePreview)
 		menuEdit.addAction(self.actionPreview)
+		menuEdit.addAction(self.actionTableMode)
 		menuEdit.addSeparator()
 		menuEdit.addAction(self.actionFullScreen)
 		menuEdit.addAction(self.actionConfig)
@@ -319,6 +299,7 @@ class ReTextWindow(QMainWindow):
 		self.searchEdit.returnPressed.connect(self.find)
 		self.csBox = QCheckBox(self.tr('Case sensitively'), self.searchBar)
 		self.searchBar.addWidget(self.searchEdit)
+		self.searchBar.addSeparator()
 		self.searchBar.addWidget(self.csBox)
 		self.searchBar.addAction(self.actionFindPrev)
 		self.searchBar.addAction(self.actionFind)
@@ -329,27 +310,26 @@ class ReTextWindow(QMainWindow):
 			timer = QTimer(self)
 			timer.start(60000)
 			timer.timeout.connect(self.saveAll)
-		self.ind = 0
-		self.tabWidget.addTab(self.createTab(""), self.tr('New document'))
+		self.ind = None
 		if enchant_available:
 			self.sl = globalSettings.spellCheckLocale
 			if self.sl:
 				try:
 					enchant.Dict(self.sl)
 				except Exception as e:
-					print(e)
+					print(e, file=sys.stderr)
 					self.sl = None
 			if globalSettings.spellCheck:
 				self.actionEnableSC.setChecked(True)
 				self.enableSC(True)
-	
+
 	def initConfig(self):
 		self.font = None
 		if globalSettings.font:
 			self.font = QFont(globalSettings.font)
 		if self.font and globalSettings.fontSize:
 			self.font.setPointSize(globalSettings.fontSize)
-	
+
 	def initTabWidget(self):
 		def dragEnterEvent(e):
 			e.acceptProposedAction()
@@ -362,7 +342,7 @@ class ReTextWindow(QMainWindow):
 		self.tabWidget.setAcceptDrops(True)
 		self.tabWidget.dragEnterEvent = dragEnterEvent
 		self.tabWidget.dropEvent = dropEvent
-	
+
 	def act(self, name, icon=None, trig=None, trigbool=None, shct=None):
 		if not isinstance(shct, QKeySequence):
 			shct = QKeySequence(shct)
@@ -378,15 +358,15 @@ class ReTextWindow(QMainWindow):
 		if shct:
 			action.setShortcut(shct)
 		return action
-	
+
 	def actIcon(self, name):
 		return QIcon.fromTheme(name, QIcon(icon_path+name+'.png'))
-	
+
 	def printError(self):
 		import traceback
-		print('Exception occured while parsing document:')
+		print('Exception occured while parsing document:', file=sys.stderr)
 		traceback.print_exc()
-	
+
 	def getSplitter(self, index):
 		splitter = QSplitter(Qt.Horizontal)
 		# Give both boxes a minimum size so the minimumSizeHint will be
@@ -397,25 +377,14 @@ class ReTextWindow(QMainWindow):
 		splitter.setSizes((50, 50))
 		splitter.setChildrenCollapsible(False)
 		return splitter
-	
+
 	def getWebView(self):
 		webView = QWebView()
 		if not globalSettings.handleWebLinks:
 			webView.page().setLinkDelegationPolicy(QWebPage.DelegateExternalLinks)
-			webView.page().linkClicked.connect(self.linkClicked)
+			webView.page().linkClicked.connect(QDesktopServices.openUrl)
 		return webView
-	
-	def linkClicked(self, url):
-		urlstr = url.toString()
-		if urlstr.startswith('file://') or ':/' not in urlstr:
-			self.previewBoxes[self.ind].load(url)
-		elif urlstr.startswith('#'):
-			self.previewBoxes[self.ind].page().mainFrame().scrollToAnchor(urlstr[1:])
-		elif urlstr.startswith('about:blank#'):
-			self.previewBoxes[self.ind].page().mainFrame().scrollToAnchor(urlstr[12:])
-		else:
-			QDesktopServices.openUrl(url)
-	
+
 	def createTab(self, fileName):
 		self.previewBlocked = False
 		self.editBoxes.append(ReTextEdit(self))
@@ -435,9 +404,9 @@ class ReTextWindow(QMainWindow):
 		self.markups.append(self.getMarkup(fileName))
 		self.highlighters[-1].docType = (markupClass.name if markupClass else '')
 		liveMode = globalSettings.restorePreviewState and globalSettings.previewState
-		self.apc.append(liveMode)
-		self.alpc.append(liveMode)
-		self.aptc.append(False)
+		self.actionPreviewChecked.append(liveMode)
+		self.actionLivePreviewChecked.append(liveMode)
+		self.actionPlainTextChecked.append(False)
 		metrics = QFontMetrics(self.editBoxes[-1].font())
 		self.editBoxes[-1].setTabStopWidth(globalSettings.tabWidth * metrics.width(' '))
 		self.editBoxes[-1].textChanged.connect(self.updateLivePreviewBox)
@@ -446,7 +415,7 @@ class ReTextWindow(QMainWindow):
 		self.editBoxes[-1].copyAvailable.connect(self.enableCopy)
 		self.editBoxes[-1].document().modificationChanged.connect(self.modificationChanged)
 		return self.getSplitter(-1)
-	
+
 	def closeTab(self, ind):
 		if self.maybeSave(ind):
 			if self.tabWidget.count() == 1:
@@ -456,11 +425,11 @@ class ReTextWindow(QMainWindow):
 			del self.highlighters[ind]
 			del self.markups[ind]
 			del self.fileNames[ind]
-			del self.apc[ind]
-			del self.alpc[ind]
-			del self.aptc[ind]
+			del self.actionPreviewChecked[ind]
+			del self.actionLivePreviewChecked[ind]
+			del self.actionPlainTextChecked[ind]
 			self.tabWidget.removeTab(ind)
-	
+
 	def getMarkupClass(self, fileName=None):
 		if fileName is None:
 			fileName = self.fileNames[self.ind]
@@ -472,14 +441,14 @@ class ReTextWindow(QMainWindow):
 			if markupClass:
 				return markupClass
 		return self.defaultMarkup
-	
+
 	def getMarkup(self, fileName=None):
 		if fileName is None:
 			fileName = self.fileNames[self.ind]
 		markupClass = self.getMarkupClass(fileName=fileName)
 		if markupClass and markupClass.available():
 			return markupClass(filename=fileName)
-	
+
 	def docTypeChanged(self):
 		oldType = self.highlighters[self.ind].docType
 		markupClass = self.getMarkupClass()
@@ -496,32 +465,36 @@ class ReTextWindow(QMainWindow):
 		self.actionUnderline.setEnabled(dtMarkdown)
 		self.actionBold.setEnabled(dtMkdOrReST)
 		self.actionItalic.setEnabled(dtMkdOrReST)
-	
+		canReload = bool(self.fileNames[self.ind]) and not self.autoSaveActive()
+		self.actionSetEncoding.setEnabled(canReload)
+		self.actionReload.setEnabled(canReload)
+
 	def changeIndex(self, ind):
 		if ind > -1:
-			self.actionPlainText.setChecked(self.aptc[ind])
-			self.actionPerfectHtml.setDisabled(self.aptc[ind])
-			self.actionViewHtml.setDisabled(self.aptc[ind])
+			self.actionPlainText.setChecked(self.actionPlainTextChecked[ind])
+			self.actionSaveHtml.setDisabled(self.actionPlainTextChecked[ind])
+			self.actionViewHtml.setDisabled(self.actionPlainTextChecked[ind])
 			self.actionUndo.setEnabled(self.editBoxes[ind].document().isUndoAvailable())
 			self.actionRedo.setEnabled(self.editBoxes[ind].document().isRedoAvailable())
 			self.actionCopy.setEnabled(self.editBoxes[ind].textCursor().hasSelection())
 			self.actionCut.setEnabled(self.editBoxes[ind].textCursor().hasSelection())
-			self.actionPreview.setChecked(self.apc[ind])
-			self.actionLivePreview.setChecked(self.alpc[ind])
-			self.editBar.setDisabled(self.apc[ind])
+			self.actionPreview.setChecked(self.actionPreviewChecked[ind])
+			self.actionLivePreview.setChecked(self.actionLivePreviewChecked[ind])
+			self.actionTableMode.setChecked(self.editBoxes[ind].tableModeEnabled)
+			self.editBar.setDisabled(self.actionPreviewChecked[ind])
 		self.ind = ind
 		if self.fileNames[ind]:
 			self.setCurrentFile()
 		else:
-			setWindowTitle(self, self.tr('New document') + '[*]')
+			self.setWindowTitle(self.tr('New document') + '[*]')
 			self.docTypeChanged()
 		self.modificationChanged(self.editBoxes[ind].document().isModified())
 		if globalSettings.restorePreviewState:
-			globalSettings.previewState = self.alpc[ind]
-		if self.alpc[ind]:
+			globalSettings.previewState = self.actionLivePreviewChecked[ind]
+		if self.actionLivePreviewChecked[ind]:
 			self.enableLivePreview(True)
 		self.editBoxes[self.ind].setFocus(Qt.OtherFocusReason)
-	
+
 	def changeFont(self):
 		if not self.font:
 			self.font = QFont()
@@ -533,9 +506,9 @@ class ReTextWindow(QMainWindow):
 			self.font.setPointSize(fd[0].pointSize())
 			settings.setValue('fontSize', fd[0].pointSize())
 			self.updatePreviewBox()
-	
+
 	def preview(self, viewmode):
-		self.apc[self.ind] = viewmode
+		self.actionPreviewChecked[self.ind] = viewmode
 		if self.actionLivePreview.isChecked():
 			self.actionLivePreview.setChecked(False)
 			return self.enableLivePreview(False)
@@ -544,19 +517,19 @@ class ReTextWindow(QMainWindow):
 		self.previewBoxes[self.ind].setVisible(viewmode)
 		if viewmode:
 			self.updatePreviewBox()
-	
+
 	def enableLivePreview(self, livemode):
 		if globalSettings.restorePreviewState:
 			globalSettings.previewState = livemode
-		self.alpc[self.ind] = livemode
-		self.apc[self.ind] = livemode
+		self.actionLivePreviewChecked[self.ind] = livemode
+		self.actionPreviewChecked[self.ind] = livemode
 		self.actionPreview.setChecked(livemode)
 		self.editBar.setEnabled(True)
 		self.previewBoxes[self.ind].setVisible(livemode)
 		self.editBoxes[self.ind].setVisible(True)
 		if livemode:
 			self.updatePreviewBox()
-	
+
 	def enableWebKit(self, enable):
 		globalSettings.useWebKit = enable
 		oldind = self.ind
@@ -570,25 +543,25 @@ class ReTextWindow(QMainWindow):
 			splitter = self.getSplitter(self.ind)
 			self.tabWidget.addTab(splitter, self.getDocumentTitle(baseName=True))
 			self.updatePreviewBox()
-			self.previewBoxes[self.ind].setVisible(self.apc[self.ind])
+			self.previewBoxes[self.ind].setVisible(self.actionPreviewChecked[self.ind])
 		self.ind = oldind
 		self.tabWidget.setCurrentIndex(self.ind)
-	
+
 	def enableCopy(self, copymode):
 		self.actionCopy.setEnabled(copymode)
 		self.actionCut.setEnabled(copymode)
-	
+
 	def enableFullScreen(self, yes):
 		if yes:
 			self.showFullScreen()
 		else:
 			self.showNormal()
-	
+
 	def openConfigDialog(self):
 		dlg = ConfigDialog(self)
-		setWindowTitle(dlg, self.tr('Preferences'))
+		dlg.setWindowTitle(self.tr('Preferences'))
 		dlg.show()
-	
+
 	def enableSC(self, yes):
 		if yes:
 			if self.sl:
@@ -598,19 +571,18 @@ class ReTextWindow(QMainWindow):
 		else:
 			self.setAllDictionaries(None)
 		globalSettings.spellCheck = yes
-	
+
 	def setAllDictionaries(self, dictionary):
 		for hl in self.highlighters:
 			hl.dictionary = dictionary
 			hl.rehighlight()
-	
+
 	def changeLocale(self):
 		if self.sl:
 			localedlg = LocaleDialog(self, defaultText=self.sl)
 		else:
 			localedlg = LocaleDialog(self)
-		localedlg.setWindowTitle(dialogTitle)
-		if localedlg.exec_() != QDialog.Accepted:
+		if localedlg.exec() != QDialog.Accepted:
 			return
 		sl = localedlg.localeEdit.text()
 		setdefault = localedlg.checkBox.isChecked()
@@ -619,7 +591,7 @@ class ReTextWindow(QMainWindow):
 				sl = str(sl)
 				enchant.Dict(sl)
 			except Exception as e:
-				QMessageBox.warning(self, dialogTitle, str(e))
+				QMessageBox.warning(self, '', str(e))
 			else:
 				self.sl = sl
 				self.enableSC(self.actionEnableSC.isChecked())
@@ -628,35 +600,38 @@ class ReTextWindow(QMainWindow):
 			self.enableSC(self.actionEnableSC.isChecked())
 		if setdefault:
 			globalSettings.spellCheckLocale = sl
-	
+
 	def searchBarVisibilityChanged(self, visible):
 		self.actionSearch.setChecked(visible)
 		if visible:
 			self.searchEdit.setFocus(Qt.ShortcutFocusReason)
-	
+
 	def find(self, back=False):
-		flags = 0
+		flags = QTextDocument.FindFlags()
 		if back:
-			flags = QTextDocument.FindBackward
+			flags |= QTextDocument.FindBackward
 		if self.csBox.isChecked():
-			flags = flags | QTextDocument.FindCaseSensitively
+			flags |= QTextDocument.FindCaseSensitively
 		text = self.searchEdit.text()
-		if not self.findMain(text, flags):
-			if text in self.editBoxes[self.ind].toPlainText():
-				cursor = self.editBoxes[self.ind].textCursor()
-				if back:
-					cursor.movePosition(QTextCursor.End)
-				else:
-					cursor.movePosition(QTextCursor.Start)
-				self.editBoxes[self.ind].setTextCursor(cursor)
-				self.findMain(text, flags)
-	
-	def findMain(self, text, flags):
-		if flags:
-			return self.editBoxes[self.ind].find(text, flags)
-		else:
-			return self.editBoxes[self.ind].find(text)
-	
+		editBox = self.editBoxes[self.ind]
+		cursor = editBox.textCursor()
+		newCursor = editBox.document().find(text, cursor, flags)
+		if not newCursor.isNull():
+			editBox.setTextCursor(newCursor)
+			return self.setSearchEditColor(True)
+		cursor.movePosition(QTextCursor.End if back else QTextCursor.Start)
+		newCursor = editBox.document().find(text, cursor, flags)
+		if not newCursor.isNull():
+			editBox.setTextCursor(newCursor)
+			return self.setSearchEditColor(True)
+		self.setSearchEditColor(False)
+
+	def setSearchEditColor(self, found):
+		palette = self.searchEdit.palette()
+		palette.setColor(QPalette.Active, QPalette.Base,
+		                 Qt.white if found else QColor(255, 102, 102))
+		self.searchEdit.setPalette(palette)
+
 	def getHtml(self, includeStyleSheet=True, includeTitle=True,
 	            includeMeta=False, styleForWebKit=False, webenv=False):
 		if self.markups[self.ind] is None:
@@ -686,7 +661,7 @@ class ReTextWindow(QMainWindow):
 		cssFileName = self.getDocumentTitle(baseName=True)+'.css'
 		if QFile(cssFileName).exists():
 			headers += '<link rel="stylesheet" type="text/css" href="%s">\n' \
-			% QUrl.fromLocalFile(QFileInfo(cssFileName).absoluteFilePath()).toString()
+			% cssFileName
 		if includeMeta:
 			headers += '<meta name="generator" content="%s %s">\n' % \
 			(app_name, app_version)
@@ -694,7 +669,7 @@ class ReTextWindow(QMainWindow):
 		return self.markups[self.ind].get_whole_html(text,
 			custom_headers=headers, include_stylesheet=includeStyleSheet,
 			fallback_title=fallbackTitle, webenv=webenv)
-	
+
 	def updatePreviewBox(self):
 		self.previewBlocked = False
 		pb = self.previewBoxes[self.ind]
@@ -717,56 +692,47 @@ class ReTextWindow(QMainWindow):
 				html = self.getHtml(styleForWebKit=(not textedit))
 			except Exception:
 				return self.printError()
-			if not textedit and ('<script ' in html):
-				# Work-around a bug in QtWebKit
-				# by saving the html locally
-				tempFile = QTemporaryFile('retext-XXXXXX.html')
-				tempFile.setAutoRemove(False)
-				tempFile.open(QIODevice.WriteOnly)
-				stream = QTextStream(tempFile)
-				stream << html
-				tempFile.close()
-				pb.loadFinished.connect(lambda ok: tempFile.remove())
-				pb.load(QUrl.fromLocalFile(tempFile.fileName()))
-			else:
+			if textedit:
 				pb.setHtml(html)
+			else:
+				pb.setHtml(html, QUrl.fromLocalFile(self.fileNames[self.ind]))
 		if self.font and textedit:
 			pb.document().setDefaultFont(self.font)
 		if textedit:
 			scrollbar.setValue(scrollbar.maximum() - disttobottom)
 		else:
 			frame.setScrollPosition(scrollpos)
-	
+
 	def updateLivePreviewBox(self):
 		if self.actionLivePreview.isChecked() and self.previewBlocked == False:
 			self.previewBlocked = True
 			QTimer.singleShot(1000, self.updatePreviewBox)
-	
+
 	def startWpgen(self):
 		if not self.fileNames[self.ind]:
-			return QMessageBox.warning(self, dialogTitle, self.tr("Please, save the file somewhere."))
+			return QMessageBox.warning(self, '', self.tr("Please, save the file somewhere."))
 		if not QFile.exists("template.html"):
 			try:
 				wpInit()
 			except IOError as e:
 				e = str(e)
-				return QMessageBox.warning(self, dialogTitle, self.tr(
+				return QMessageBox.warning(self, '', self.tr(
 				'Failed to copy default template, please create template.html manually.')
 				+ '\n\n' + e)
 		wpUpdateAll()
-		msgBox = QMessageBox(QMessageBox.Information, dialogTitle,
+		msgBox = QMessageBox(QMessageBox.Information, '',
 		self.tr("Webpages saved in <code>html</code> directory."), QMessageBox.Ok)
 		showButton = msgBox.addButton(self.tr("Show directory"), QMessageBox.AcceptRole)
-		msgBox.exec_()
+		msgBox.exec()
 		if msgBox.clickedButton() == showButton:
 			QDesktopServices.openUrl(QUrl.fromLocalFile(QDir('html').absolutePath()))
-	
+
 	def showInDir(self):
 		if self.fileNames[self.ind]:
 			QDesktopServices.openUrl(QUrl.fromLocalFile(QFileInfo(self.fileNames[self.ind]).path()))
 		else:
-			QMessageBox.warning(self, dialogTitle, self.tr("Please, save the file somewhere."))
-	
+			QMessageBox.warning(self, '', self.tr("Please, save the file somewhere."))
+
 	def setCurrentFile(self):
 		self.setWindowTitle("")
 		self.tabWidget.setTabText(self.ind, self.getDocumentTitle(baseName=True))
@@ -780,14 +746,17 @@ class ReTextWindow(QMainWindow):
 		writeListToSettings("recentFileList", files)
 		QDir.setCurrent(QFileInfo(self.fileNames[self.ind]).dir().path())
 		self.docTypeChanged()
-		self.actionSetEncoding.setEnabled(
-			bool(self.fileNames[self.ind]) and not self.autoSaveActive())
-	
-	def createNew(self):
+
+	def createNew(self, text=None):
 		self.tabWidget.addTab(self.createTab(""), self.tr("New document"))
 		self.ind = self.tabWidget.count()-1
 		self.tabWidget.setCurrentIndex(self.ind)
-	
+		if text:
+			self.editBoxes[self.ind].textCursor().insertText(text)
+
+	def switchTab(self, shift=1):
+		self.tabWidget.setCurrentIndex((self.ind + shift) % self.tabWidget.count())
+
 	def updateRecentFiles(self):
 		self.menuRecentFiles.clear()
 		self.recentFilesActions = []
@@ -800,17 +769,17 @@ class ReTextWindow(QMainWindow):
 		writeListToSettings("recentFileList", files)
 		for action in self.recentFilesActions:
 			self.menuRecentFiles.addAction(action)
-	
+
 	def markupFunction(self, markup):
 		return lambda: self.setDefaultMarkup(markup)
-	
+
 	def openFunction(self, fileName):
 		return lambda: self.openFileWrapper(fileName)
-	
+
 	def extensionFuntion(self, data):
 		return lambda: \
 		self.runExtensionCommand(data['Exec'], data['FileFilter'], data['DefaultExtension'])
-	
+
 	def getExportExtensionsList(self):
 		extensions = []
 		for extsprefix in datadirs:
@@ -841,10 +810,10 @@ class ReTextWindow(QMainWindow):
 					action.setIcon(self.actIcon(extension['Icon']))
 				mimetype = extension['MimeType'] if 'MimeType' in extension else None
 			except KeyError:
-				print('Failed to parse extension: Name is required')
+				print('Failed to parse extension: Name is required', file=sys.stderr)
 			else:
 				self.extensionActions.append((action, mimetype))
-	
+
 	def updateExtensionsVisibility(self):
 		markupClass = self.getMarkupClass()
 		for action in self.extensionActions:
@@ -861,7 +830,7 @@ class ReTextWindow(QMainWindow):
 			else:
 				enabled = False
 			action[0].setEnabled(enabled)
-	
+
 	def readExtension(self, fileName):
 		extFile = QFile(fileName)
 		extFile.open(QIODevice.ReadOnly)
@@ -874,20 +843,17 @@ class ReTextWindow(QMainWindow):
 				extension[line[:index].rstrip()] = line[index+1:].lstrip()
 		extFile.close()
 		return extension
-	
+
 	def openFile(self):
 		supportedExtensions = ['.txt']
 		for markup in markups.get_all_markups():
 			supportedExtensions += markup.file_extensions
 		fileFilter = ' (' + str.join(' ', ['*'+ext for ext in supportedExtensions]) + ');;'
 		fileNames = QFileDialog.getOpenFileNames(self, self.tr("Select one or several files to open"), "",
-		self.tr("Supported files") + fileFilter + self.tr("All files (*)"))
-		if isinstance(fileNames, tuple):
-			# PySide or PyQt5
-			fileNames = fileNames[0]
-		for fileName in fileNames:
+			self.tr("Supported files") + fileFilter + self.tr("All files (*)"))
+		for fileName in fileNames[0]:
 			self.openFileWrapper(fileName)
-	
+
 	def openFileWrapper(self, fileName):
 		if not fileName:
 			return
@@ -900,14 +866,19 @@ class ReTextWindow(QMainWindow):
 		if exists:
 			self.tabWidget.setCurrentIndex(ex)
 		elif QFile.exists(fileName):
-			if self.fileNames[self.ind] or self.editBoxes[self.ind].toPlainText() \
-			or self.editBoxes[self.ind].document().isModified():
+			noEmptyTab = (
+				(self.ind is None) or
+				self.fileNames[self.ind] or
+				self.editBoxes[self.ind].toPlainText() or
+				self.editBoxes[self.ind].document().isModified()
+			)
+			if noEmptyTab:
 				self.tabWidget.addTab(self.createTab(fileName), "")
 				self.ind = self.tabWidget.count()-1
 				self.tabWidget.setCurrentIndex(self.ind)
 			self.fileNames[self.ind] = fileName
 			self.openFileMain()
-	
+
 	def openFileMain(self, encoding=None):
 		openfile = QFile(self.fileNames[self.ind])
 		openfile.open(QIODevice.ReadOnly)
@@ -933,23 +904,23 @@ class ReTextWindow(QMainWindow):
 		self.setCurrentFile()
 		editBox.document().setModified(modified)
 		self.setWindowModified(modified)
-	
+
 	def showEncodingDialog(self):
 		if not self.maybeSave(self.ind):
 			return
-		encoding, ok = QInputDialog.getItem(self, dialogTitle,
+		encoding, ok = QInputDialog.getItem(self, '',
 			self.tr('Select file encoding from the list:'),
 			[bytes(b).decode() for b in QTextCodec.availableCodecs()],
 			0, False)
 		if ok:
 			self.openFileMain(encoding)
-	
+
 	def saveFile(self):
 		self.saveFileMain(dlg=False)
-	
+
 	def saveFileAs(self):
 		self.saveFileMain(dlg=True)
-	
+
 	def saveAll(self):
 		oldind = self.ind
 		for self.ind in range(self.tabWidget.count()):
@@ -957,7 +928,7 @@ class ReTextWindow(QMainWindow):
 				self.saveFileCore(self.fileNames[self.ind])
 				self.editBoxes[self.ind].document().setModified(False)
 		self.ind = oldind
-	
+
 	def saveFileMain(self, dlg):
 		if (not self.fileNames[self.ind]) or dlg:
 			markupClass = self.getMarkupClass()
@@ -970,7 +941,8 @@ class ReTextWindow(QMainWindow):
 					% markupClass.name + ' (' + str.join(' ',
 					('*'+extension for extension in markupClass.file_extensions)) + ')'
 				ext = markupClass.default_extension
-			newFileName = getSaveFileName(self, self.tr("Save file"), "", defaultExt)
+			newFileName = QFileDialog.getSaveFileName(self,
+				self.tr("Save file"), "", defaultExt)[0]
 			if newFileName:
 				if not QFileInfo(newFileName).suffix():
 					newFileName += ext
@@ -984,10 +956,10 @@ class ReTextWindow(QMainWindow):
 				self.setWindowModified(False)
 				return True
 			else:
-				QMessageBox.warning(self, dialogTitle,
+				QMessageBox.warning(self, '',
 				self.tr("Cannot save to file because it is read-only!"))
 		return False
-	
+
 	def saveFileCore(self, fn):
 		savefile = QFile(fn)
 		result = savefile.open(QIODevice.WriteOnly)
@@ -996,12 +968,12 @@ class ReTextWindow(QMainWindow):
 			savestream << self.editBoxes[self.ind].toPlainText()
 			savefile.close()
 		return result
-	
+
 	def saveHtml(self, fileName):
 		if not QFileInfo(fileName).suffix():
 			fileName += ".html"
 		try:
-			htmltext = self.getHtml(includeStyleSheet=False, includeMeta=True, 
+			htmltext = self.getHtml(includeStyleSheet=False, includeMeta=True,
 			webenv=True)
 		except Exception:
 			return self.printError()
@@ -1010,7 +982,7 @@ class ReTextWindow(QMainWindow):
 		html = QTextStream(htmlFile)
 		html << htmltext
 		htmlFile.close()
-	
+
 	def textDocument(self):
 		td = QTextDocument()
 		td.setMetaInformation(QTextDocument.DocumentTitle, self.getDocumentTitle())
@@ -1023,26 +995,28 @@ class ReTextWindow(QMainWindow):
 		if self.font:
 			td.setDefaultFont(self.font)
 		return td
-	
+
 	def saveOdf(self):
 		try:
 			document = self.textDocument()
 		except Exception:
 			return self.printError()
-		fileName = getSaveFileName(self, self.tr("Export document to ODT"), "",
-			self.tr("OpenDocument text files (*.odt)"))
+		fileName = QFileDialog.getSaveFileName(self,
+			self.tr("Export document to ODT"), "",
+			self.tr("OpenDocument text files (*.odt)"))[0]
 		if not QFileInfo(fileName).suffix():
 			fileName += ".odt"
-		writer = QtGui.QTextDocumentWriter(fileName)
+		writer = QTextDocumentWriter(fileName)
 		writer.setFormat("odf")
 		writer.write(document)
-	
-	def saveFilePerfect(self):
-		fileName = getSaveFileName(self, self.tr("Save file"), "",
-			self.tr("HTML files (*.html *.htm)"))
+
+	def saveFileHtml(self):
+		fileName = QFileDialog.getSaveFileName(self,
+			self.tr("Save file"), "",
+			self.tr("HTML files (*.html *.htm)"))[0]
 		if fileName:
 			self.saveHtml(fileName)
-	
+
 	def getDocumentForPrint(self):
 		if globalSettings.useWebKit:
 			return self.previewBoxes[self.ind]
@@ -1050,17 +1024,18 @@ class ReTextWindow(QMainWindow):
 			return self.textDocument()
 		except Exception:
 			self.printError()
-	
+
 	def standardPrinter(self):
 		printer = QPrinter(QPrinter.HighResolution)
 		printer.setDocName(self.getDocumentTitle())
 		printer.setCreator(app_name+" "+app_version)
 		return printer
-	
+
 	def savePdf(self):
 		self.updatePreviewBox()
-		fileName = getSaveFileName(self, self.tr("Export document to PDF"),
-			"", self.tr("PDF files (*.pdf)"))
+		fileName = QFileDialog.getSaveFileName(self,
+			self.tr("Export document to PDF"),
+			"", self.tr("PDF files (*.pdf)"))[0]
 		if fileName:
 			if not QFileInfo(fileName).suffix():
 				fileName += ".pdf"
@@ -1069,34 +1044,35 @@ class ReTextWindow(QMainWindow):
 			printer.setOutputFileName(fileName)
 			document = self.getDocumentForPrint()
 			if document != None:
-				document.print_(printer)
-	
+				document.print(printer)
+
 	def printFile(self):
 		self.updatePreviewBox()
 		printer = self.standardPrinter()
 		dlg = QPrintDialog(printer, self)
-		setWindowTitle(dlg, self.tr("Print document"))
-		if (dlg.exec_() == QDialog.Accepted):
+		dlg.setWindowTitle(self.tr("Print document"))
+		if (dlg.exec() == QDialog.Accepted):
 			document = self.getDocumentForPrint()
 			if document != None:
-				document.print_(printer)
-	
+				document.print(printer)
+
 	def printPreview(self):
 		document = self.getDocumentForPrint()
 		if document == None:
 			return
 		printer = self.standardPrinter()
 		preview = QPrintPreviewDialog(printer, self)
-		preview.paintRequested.connect(document.print_)
-		preview.exec_()
-	
+		preview.paintRequested.connect(document.print)
+		preview.exec()
+
 	def runExtensionCommand(self, command, filefilter, defaultext):
 		of = ('%of' in command)
 		html = ('%html' in command)
 		if of:
 			if defaultext and not filefilter:
 				filefilter = '*'+defaultext
-			fileName = getSaveFileName(self, self.tr('Export document'), '', filefilter)
+			fileName = QFileDialog.getSaveFileName(self,
+				self.tr('Export document'), '', filefilter)[0]
 			if not fileName:
 				return
 			if defaultext and not QFileInfo(fileName).suffix():
@@ -1114,12 +1090,12 @@ class ReTextWindow(QMainWindow):
 			Popen(str(command), shell=True).wait()
 		except Exception as error:
 			errorstr = str(error)
-			QMessageBox.warning(self, dialogTitle, self.tr('Failed to execute the command:')
+			QMessageBox.warning(self, '', self.tr('Failed to execute the command:')
 			+ '\n' + errorstr)
 		QFile(tmpname).remove()
 		if of:
 			QFile('out'+defaultext).rename(fileName)
-	
+
 	def getDocumentTitle(self, baseName=False):
 		markup = self.markups[self.ind]
 		realTitle = ''
@@ -1136,20 +1112,20 @@ class ReTextWindow(QMainWindow):
 			basename = fileinfo.completeBaseName()
 			return (basename if basename else fileinfo.fileName())
 		return self.tr("New document")
-	
+
 	def autoSaveActive(self):
 		return self.autoSaveEnabled and self.fileNames[self.ind] and \
 		QFileInfo(self.fileNames[self.ind]).isWritable()
-	
+
 	def modificationChanged(self, changed):
 		if self.autoSaveActive():
 			changed = False
 		self.actionSave.setEnabled(changed)
 		self.setWindowModified(changed)
-	
+
 	def clipboardDataChanged(self):
 		self.actionPaste.setEnabled(QApplication.instance().clipboard().mimeData().hasText())
-	
+
 	def insertChars(self, chars):
 		tc = self.editBoxes[self.ind].textCursor()
 		if tc.hasSelection():
@@ -1162,28 +1138,30 @@ class ReTextWindow(QMainWindow):
 				tc.insertText(chars+tc.selectedText()+chars)
 		else:
 			tc.insertText(chars)
-	
-	def insertTag(self, num):
-		if num:
-			ut = self.usefulTags[num-1]
-			arg = ' style=""' if ut == 'span' else '' 
-			tc = self.editBoxes[self.ind].textCursor()
-			if ut == 'img':
-				toinsert = ('<a href="' + tc.selectedText() +
-				'" target="_blank"><img src="' + tc.selectedText() + '"/></a>')
-			elif ut == 'a':
-				toinsert = ('<a href="' + tc.selectedText() +
-				'" target="_blank">' + tc.selectedText() + '</a>')
-			else:
-				toinsert = '<'+ut+arg+'>'+tc.selectedText()+'</'+ut+'>'
-			tc.insertText(toinsert)
+
+	def insertTag(self, ut):
+		if not ut:
+			return
+		if isinstance(ut, int):
+			ut = self.usefulTags[ut - 1]
+		arg = ' style=""' if ut == 'span' else ''
+		tc = self.editBoxes[self.ind].textCursor()
+		if ut == 'img':
+			toinsert = ('<a href="' + tc.selectedText() +
+			'" target="_blank"><img src="' + tc.selectedText() + '"/></a>')
+		elif ut == 'a':
+			toinsert = ('<a href="' + tc.selectedText() +
+			'" target="_blank">' + tc.selectedText() + '</a>')
+		else:
+			toinsert = '<'+ut+arg+'>'+tc.selectedText()+'</'+ut+'>'
+		tc.insertText(toinsert)
 		self.tagsBox.setCurrentIndex(0)
-	
+
 	def insertSymbol(self, num):
 		if num:
 			self.editBoxes[self.ind].insertPlainText('&'+self.usefulChars[num-1]+';')
 		self.symbolBox.setCurrentIndex(0)
-	
+
 	def maybeSave(self, ind):
 		if self.autoSaveActive():
 			self.saveFileCore(self.fileNames[self.ind])
@@ -1191,7 +1169,7 @@ class ReTextWindow(QMainWindow):
 		if not self.editBoxes[ind].document().isModified():
 			return True
 		self.tabWidget.setCurrentIndex(ind)
-		ret = QMessageBox.warning(self, dialogTitle,
+		ret = QMessageBox.warning(self, '',
 			self.tr("The document has been modified.\nDo you want to save your changes?"),
 			QMessageBox.Save | QMessageBox.Discard | QMessageBox.Cancel)
 		if ret == QMessageBox.Save:
@@ -1199,7 +1177,7 @@ class ReTextWindow(QMainWindow):
 		elif ret == QMessageBox.Cancel:
 			return False
 		return True
-	
+
 	def closeEvent(self, closeevent):
 		for self.ind in range(self.tabWidget.count()):
 			if not self.maybeSave(self.ind):
@@ -1207,7 +1185,7 @@ class ReTextWindow(QMainWindow):
 		if globalSettings.saveWindowGeometry and not self.isMaximized():
 			globalSettings.windowGeometry = self.saveGeometry()
 		closeevent.accept()
-	
+
 	def viewHtml(self):
 		htmlDlg = HtmlDialog(self)
 		try:
@@ -1215,16 +1193,16 @@ class ReTextWindow(QMainWindow):
 		except Exception:
 			return self.printError()
 		winTitle = self.getDocumentTitle(baseName=True)
-		setWindowTitle(htmlDlg, winTitle+" ("+self.tr("HTML code")+")")
+		htmlDlg.setWindowTitle(winTitle+" ("+self.tr("HTML code")+")")
 		htmlDlg.textEdit.setPlainText(htmltext.rstrip())
 		htmlDlg.hl.rehighlight()
 		htmlDlg.show()
 		htmlDlg.raise_()
 		htmlDlg.activateWindow()
-	
+
 	def openHelp(self):
 		QDesktopServices.openUrl(QUrl('http://sourceforge.net/p/retext/home/Help and Support'))
-	
+
 	def aboutDialog(self):
 		QMessageBox.about(self, self.aboutWindowTitle,
 		'<p><b>'+app_name+' '+app_version+'</b><br>'+self.tr('Simple but powerful editor'
@@ -1234,13 +1212,13 @@ class ReTextWindow(QMainWindow):
 		+'</a> | <a href="http://daringfireball.net/projects/markdown/syntax">'+self.tr('Markdown syntax')
 		+'</a> | <a href="http://docutils.sourceforge.net/docs/user/rst/quickref.html">'
 		+self.tr('reStructuredText syntax')+'</a></p>')
-	
+
 	def enablePlainText(self, value):
-		self.aptc[self.ind] = value
-		self.actionPerfectHtml.setDisabled(value)
+		self.actionPlainTextChecked[self.ind] = value
+		self.actionSaveHtml.setDisabled(value)
 		self.actionViewHtml.setDisabled(value)
 		self.docTypeChanged()
-	
+
 	def setDefaultMarkup(self, markup):
 		self.defaultMarkup = markup
 		defaultName = markups.get_available_markups()[0].name
