@@ -3,85 +3,113 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Behavior</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Automatically save documents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Restore window geometry</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Restore live preview state</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Open external links in ReText window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Open unknown files in plain text mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Editor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Highlight current line</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Show line numbers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Tab key inserts spaces</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Tabulation width</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Display right margin at column</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Interface</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="54"/>
         <source>Icon theme name</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="config.py" line="54"/>
+        <source>Markdown extensions (comma-separated)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="54"/>
+        <source>Color scheme file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="54"/>
+        <source>Stylesheet file</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FileSelectButton</name>
+    <message>
+        <location filename="config.py" line="21"/>
+        <source>(none)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="config.py" line="28"/>
+        <source>Select file to open</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="34"/>
+        <location filename="dialogs.py" line="32"/>
         <source>Enter locale name (example: en_US)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="39"/>
+        <location filename="dialogs.py" line="37"/>
         <source>Set as default</source>
         <translation type="unfinished"></translation>
     </message>
@@ -89,403 +117,423 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="92"/>
+        <location filename="window.py" line="61"/>
         <source>File toolbar</source>
         <translation>Toolbar File</translation>
     </message>
     <message>
-        <location filename="window.py" line="94"/>
+        <location filename="window.py" line="63"/>
         <source>Edit toolbar</source>
         <translation>Toolbar Modifica</translation>
     </message>
     <message>
-        <location filename="window.py" line="96"/>
+        <location filename="window.py" line="65"/>
         <source>Search toolbar</source>
         <translation>Toolbar Ricerca</translation>
     </message>
     <message>
-        <location filename="window.py" line="100"/>
+        <location filename="window.py" line="69"/>
         <source>New</source>
         <translation>Nuovo</translation>
     </message>
     <message>
-        <location filename="window.py" line="103"/>
+        <location filename="window.py" line="72"/>
         <source>Open</source>
         <translation>Apri</translation>
     </message>
     <message>
-        <location filename="window.py" line="109"/>
+        <location filename="window.py" line="80"/>
         <source>Save</source>
         <translation>Salva</translation>
     </message>
     <message>
-        <location filename="window.py" line="113"/>
+        <location filename="window.py" line="84"/>
         <source>Save as</source>
         <translation>Salva con nome</translation>
     </message>
     <message>
-        <location filename="window.py" line="115"/>
+        <location filename="window.py" line="90"/>
         <source>Print</source>
         <translation>Stampa</translation>
     </message>
     <message>
-        <location filename="window.py" line="118"/>
+        <location filename="window.py" line="93"/>
         <source>Print preview</source>
         <translation>Stampa anteprima</translation>
     </message>
     <message>
-        <location filename="window.py" line="120"/>
+        <location filename="window.py" line="95"/>
         <source>View HTML code</source>
         <translation>Vedi codice HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="121"/>
+        <location filename="window.py" line="96"/>
         <source>Change default font</source>
         <translation>Cambia il font predefinito</translation>
     </message>
     <message>
-        <location filename="window.py" line="122"/>
+        <location filename="window.py" line="97"/>
         <source>Find text</source>
         <translation>Trova testo</translation>
     </message>
     <message>
-        <location filename="window.py" line="126"/>
+        <location filename="window.py" line="101"/>
         <source>Preview</source>
         <translation>Anteprima</translation>
     </message>
     <message>
-        <location filename="window.py" line="135"/>
+        <location filename="window.py" line="110"/>
         <source>Live preview</source>
         <translation>Anteprima in diretta</translation>
     </message>
     <message>
-        <location filename="window.py" line="137"/>
+        <location filename="window.py" line="114"/>
         <source>Fullscreen mode</source>
         <translation>Schermo intero</translation>
     </message>
     <message>
-        <location filename="window.py" line="145"/>
+        <location filename="window.py" line="122"/>
         <source>Quit</source>
         <translation>Esci</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
+        <location filename="window.py" line="125"/>
         <source>Undo</source>
         <translation>Annulla</translation>
     </message>
     <message>
-        <location filename="window.py" line="150"/>
+        <location filename="window.py" line="127"/>
         <source>Redo</source>
         <translation>Ripristina</translation>
     </message>
     <message>
-        <location filename="window.py" line="152"/>
+        <location filename="window.py" line="129"/>
         <source>Copy</source>
         <translation>Copia</translation>
     </message>
     <message>
-        <location filename="window.py" line="154"/>
+        <location filename="window.py" line="131"/>
         <source>Cut</source>
         <translation>Taglia</translation>
     </message>
     <message>
-        <location filename="window.py" line="156"/>
+        <location filename="window.py" line="133"/>
         <source>Paste</source>
         <translation>Incolla</translation>
     </message>
     <message>
-        <location filename="window.py" line="166"/>
+        <location filename="window.py" line="143"/>
         <source>Enable</source>
         <translation>Attiva</translation>
     </message>
     <message>
-        <location filename="window.py" line="167"/>
+        <location filename="window.py" line="144"/>
         <source>Set locale</source>
         <translation>Imposta localizzazione</translation>
     </message>
     <message>
-        <location filename="window.py" line="168"/>
+        <location filename="window.py" line="145"/>
         <source>Plain text</source>
         <translation>Testo semplice</translation>
     </message>
     <message>
-        <location filename="window.py" line="169"/>
+        <location filename="window.py" line="146"/>
         <source>Use WebKit renderer</source>
         <translation>Usa il motore WebKit</translation>
     </message>
     <message>
-        <location filename="window.py" line="171"/>
+        <location filename="window.py" line="148"/>
         <source>Generate webpages</source>
         <translation>Genera pagine web</translation>
     </message>
     <message>
-        <location filename="window.py" line="172"/>
+        <location filename="window.py" line="149"/>
         <source>Show</source>
         <translation>Mostra</translation>
     </message>
     <message>
-        <location filename="window.py" line="173"/>
+        <location filename="window.py" line="150"/>
         <source>Next</source>
         <translation>Avanti</translation>
     </message>
     <message>
-        <location filename="window.py" line="175"/>
+        <location filename="window.py" line="152"/>
         <source>Previous</source>
         <translation>Indietro</translation>
     </message>
     <message>
-        <location filename="window.py" line="177"/>
+        <location filename="window.py" line="154"/>
         <source>Get help online</source>
         <translation>Ottieni aiuto online</translation>
     </message>
     <message>
-        <location filename="window.py" line="178"/>
+        <location filename="window.py" line="155"/>
         <source>About %s</source>
         <comment>Example of final string: About ReText</comment>
         <translation>A proposito di %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="182"/>
+        <location filename="window.py" line="159"/>
         <source>About Qt</source>
         <translation>A proposito di Qt</translation>
     </message>
     <message>
-        <location filename="window.py" line="202"/>
+        <location filename="window.py" line="179"/>
         <source>Bold</source>
         <translation>Grassetto</translation>
     </message>
     <message>
-        <location filename="window.py" line="204"/>
+        <location filename="window.py" line="181"/>
         <source>Italic</source>
         <translation>Corsivo</translation>
     </message>
     <message>
-        <location filename="window.py" line="206"/>
+        <location filename="window.py" line="183"/>
         <source>Underline</source>
         <translation>Sottolineato</translation>
     </message>
     <message>
-        <location filename="window.py" line="214"/>
+        <location filename="window.py" line="191"/>
         <source>Tags</source>
         <translation>Tag</translation>
     </message>
     <message>
-        <location filename="window.py" line="218"/>
+        <location filename="window.py" line="195"/>
         <source>Symbols</source>
         <translation>Simboli</translation>
     </message>
     <message>
-        <location filename="window.py" line="231"/>
+        <location filename="window.py" line="209"/>
         <source>File</source>
         <translation>File</translation>
     </message>
     <message>
-        <location filename="window.py" line="232"/>
+        <location filename="window.py" line="210"/>
         <source>Edit</source>
         <translation>Modifica</translation>
     </message>
     <message>
-        <location filename="window.py" line="233"/>
+        <location filename="window.py" line="211"/>
         <source>Help</source>
         <translation>Aiuto</translation>
     </message>
     <message>
-        <location filename="window.py" line="236"/>
+        <location filename="window.py" line="214"/>
         <source>Open recent</source>
         <translation>Apri recente</translation>
     </message>
     <message>
-        <location filename="window.py" line="239"/>
+        <location filename="window.py" line="217"/>
         <source>Directory</source>
         <translation>Cartella</translation>
     </message>
     <message>
-        <location filename="window.py" line="247"/>
+        <location filename="window.py" line="229"/>
         <source>Export</source>
         <translation>Esporta</translation>
     </message>
     <message>
-        <location filename="window.py" line="269"/>
+        <location filename="window.py" line="250"/>
         <source>Spell check</source>
         <translation>Correzione ortografica</translation>
     </message>
     <message>
-        <location filename="window.py" line="280"/>
+        <location filename="window.py" line="261"/>
         <source>Formatting</source>
         <translation>Formattazione</translation>
     </message>
     <message>
-        <location filename="window.py" line="317"/>
+        <location filename="window.py" line="299"/>
         <source>Search</source>
         <translation>Cerca</translation>
     </message>
     <message>
-        <location filename="window.py" line="319"/>
+        <location filename="window.py" line="301"/>
         <source>Case sensitively</source>
         <translation>Distingui maiuscole/minuscole</translation>
     </message>
     <message>
-        <location filename="window.py" line="1135"/>
+        <location filename="window.py" line="1121"/>
         <source>New document</source>
         <translation>Nuovo documento</translation>
     </message>
     <message>
-        <location filename="window.py" line="765"/>
+        <location filename="window.py" line="739"/>
         <source>Please, save the file somewhere.</source>
         <translation>Per favore, salva il file da qualche parte.</translation>
     </message>
     <message>
-        <location filename="window.py" line="754"/>
+        <location filename="window.py" line="728"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Pagine web salvate nella cartella &lt;code&gt;html&lt;/code&gt;</translation>
     </message>
     <message>
-        <location filename="window.py" line="756"/>
+        <location filename="window.py" line="730"/>
         <source>Show directory</source>
         <translation>Mostra cartella</translation>
     </message>
     <message>
-        <location filename="window.py" line="880"/>
+        <location filename="window.py" line="858"/>
         <source>Select one or several files to open</source>
         <translation>Scegli uno o più file da aprire</translation>
     </message>
     <message>
-        <location filename="window.py" line="880"/>
+        <location filename="window.py" line="858"/>
         <source>Supported files</source>
         <translation>File supportati</translation>
     </message>
     <message>
-        <location filename="window.py" line="880"/>
+        <location filename="window.py" line="858"/>
         <source>All files (*)</source>
         <translation>Tutti i file (*)</translation>
     </message>
     <message>
-        <location filename="window.py" line="962"/>
+        <location filename="window.py" line="942"/>
         <source>Plain text (*.txt)</source>
         <translation>Testo semplice (*.txt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1038"/>
+        <location filename="window.py" line="1020"/>
         <source>Save file</source>
         <translation>Salva file</translation>
     </message>
     <message>
-        <location filename="window.py" line="984"/>
+        <location filename="window.py" line="965"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Non posso salvare il file perché è read-only!</translation>
     </message>
     <message>
-        <location filename="window.py" line="1029"/>
+        <location filename="window.py" line="1010"/>
         <source>Export document to ODT</source>
         <translation>Esporta documento in ODT</translation>
     </message>
     <message>
-        <location filename="window.py" line="1029"/>
+        <location filename="window.py" line="1010"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>File di testo OpenDocumenti (*.odt)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1038"/>
+        <location filename="window.py" line="1020"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>file HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1059"/>
+        <location filename="window.py" line="1042"/>
         <source>Export document to PDF</source>
         <translation>Esporta documento su PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1059"/>
+        <location filename="window.py" line="1042"/>
         <source>PDF files (*.pdf)</source>
         <translation>File PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1075"/>
+        <location filename="window.py" line="1059"/>
         <source>Print document</source>
         <translation>Stampa documento</translation>
     </message>
     <message>
-        <location filename="window.py" line="1096"/>
+        <location filename="window.py" line="1080"/>
         <source>Export document</source>
         <translation>Esporta documento</translation>
     </message>
     <message>
-        <location filename="window.py" line="1114"/>
+        <location filename="window.py" line="1099"/>
         <source>Failed to execute the command:</source>
         <translation>Non sono riuscito ad eseguire il comando:</translation>
     </message>
     <message>
-        <location filename="window.py" line="1191"/>
+        <location filename="window.py" line="1180"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Questo documento è stato modificato.
 Vuoi salvare le tue modifiche?</translation>
     </message>
     <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1204"/>
         <source>HTML code</source>
         <translation>Codice HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="1226"/>
+        <location filename="window.py" line="1215"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Editor Markdown e reStructuredText semplice e potente</translation>
     </message>
     <message>
-        <location filename="window.py" line="1226"/>
+        <location filename="window.py" line="1215"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autore: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="1226"/>
+        <location filename="window.py" line="1215"/>
         <source>Website</source>
         <translation>Sito web</translation>
     </message>
     <message>
-        <location filename="window.py" line="1226"/>
+        <location filename="window.py" line="1215"/>
         <source>Markdown syntax</source>
         <translation>Sintassi Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="1226"/>
+        <location filename="window.py" line="1215"/>
         <source>reStructuredText syntax</source>
         <translation>Sintassi reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="965"/>
+        <location filename="window.py" line="945"/>
         <source>%s files</source>
         <comment>Example of final string: Markdown files</comment>
         <translation>File %s</translation>
     </message>
     <message>
-        <location filename="window.py" line="750"/>
+        <location filename="window.py" line="724"/>
         <source>Failed to copy default template, please create template.html manually.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="661"/>
+        <location filename="window.py" line="641"/>
         <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="277"/>
+        <location filename="window.py" line="258"/>
         <source>Default markup</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="586"/>
+        <location filename="window.py" line="564"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="106"/>
+        <location filename="window.py" line="75"/>
         <source>Set encoding</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="window.py" line="937"/>
+        <location filename="window.py" line="917"/>
         <source>Select file encoding from the list:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="window.py" line="78"/>
+        <source>Reload</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="86"/>
+        <source>Next tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="88"/>
+        <source>Previous tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="window.py" line="112"/>
+        <source>Table mode</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
